@@ -1,13 +1,16 @@
+import importlib.resources as pkg_resources
 import json
 from pathlib import Path
 
+import numpy as np
 import torchaudio  # type: ignore
 import yaml  # type: ignore
 
+import timething
 from timething import align  # type: ignore
 
 # yaml file containing all of the models
-MODELS_YAML = "timething/models.yaml"
+MODELS_YAML = "models.yaml"
 
 
 def load_config(model: str) -> align.Config:
@@ -15,14 +18,14 @@ def load_config(model: str) -> align.Config:
     Load config object for the given model key
     """
 
-    with open(MODELS_YAML, "r") as f:
-        cfg = yaml.safe_load(f)
-        return align.Config(
-            cfg[model]["model"],
-            cfg[model]["pin"],
-            cfg[model]["sampling_rate"],
-            cfg[model]["language"],
-        )
+    text = pkg_resources.read_text(timething, MODELS_YAML)
+    cfg = yaml.safe_load(text)
+    return align.Config(
+        cfg[model]["model"],
+        cfg[model]["pin"],
+        cfg[model]["sampling_rate"],
+        cfg[model]["language"],
+    )
 
 
 def load_slice(filename: Path, start_seconds: float, end_seconds: float):
@@ -81,8 +84,11 @@ def write_alignment(output_path: Path, id: str, alignment: align.Alignment):
         "sampling_rate": alignment.sampling_rate,
     }
 
+    # write any path components, e.g. for id 'audio/one.mp3.json'
+    filename = alignment_filename(output_path, id)
+    filename.parent.mkdir(parents=True, exist_ok=True)
+
     # write the file
-    filename = (output_path / id).with_suffix(".json")
     with open(filename, "w", encoding="utf8") as f:
         f.write(json.dumps(meta, indent=4, sort_keys=True, ensure_ascii=False))
 
@@ -92,13 +98,13 @@ def read_alignment(alignments_dir: Path, alignment_id: str) -> align.Alignment:
     Read Aligments json file.
     """
 
-    with open((alignments_dir / alignment_id).with_suffix(".json"), "r") as f:
+    with open(alignment_filename(alignments_dir, alignment_id), "r") as f:
         alignment_dict = json.load(f)
 
     alignment = align.Alignment(
-        None,  # log probs
-        None,  # trellis
-        None,  # backtracking path
+        np.array([]),  # log probs
+        np.array([]),  # trellis
+        np.array([]),  # backtracking path
         [],  # char segments
         [],  # word segments
         alignment_dict["n_model_frames"],
@@ -126,3 +132,12 @@ def read_alignment(alignments_dir: Path, alignment_id: str) -> align.Alignment:
     ]
 
     return alignment
+
+
+def alignment_filename(path, id):
+    """
+    From audio/one.mp3 to audio/one.mp3.json
+    """
+
+    filename = path / id
+    return filename.parent / (filename.name + ".json")
